==> p2-maven-plugin-1.1.0-sources.jar: org/reficio/p2/bundler/ArtifactBundlerRequest.java <==
/**
 * Copyright (c) 2012 Reficio (TM) - Reestablish your software! All Rights Reserved.
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.reficio.p2.bundler;

import java.io.File;

/**
 * @author Tom Bujok (tom.bujok@gmail.com)<br/>
 *         Reficio (TM) - Reestablish your software!<br/>
 *         http://www.reficio.org
 * @since 1.1.0
 */
public class ArtifactBundlerRequest {

    // jar file with binaries
    private File binaryInputFile;
    private File binaryOutputFile;
    private final boolean shouldBundleBinaryFile;

    // jar file with sources
    private File sourceInputFile;
    private File sourceOutputFile;
    private final boolean shouldBundleSourceFile;

    public ArtifactBundlerRequest(File binaryInputFile, File binaryOutputFile, File sourceInputFile, File sourceOutputFile, boolean shouldBundle) {
        this.binaryInputFile = binaryInputFile;
        this.binaryOutputFile = binaryOutputFile;
        this.sourceInputFile = sourceInputFile;
        this.sourceOutputFile = sourceOutputFile;
        this.shouldBundleBinaryFile = shouldBundle;
        this.shouldBundleSourceFile = true; // source is always (re)bundled
    }

    public File getBinaryInputFile() {
        return binaryInputFile;
    }

    public void setBinaryInputFile(File binaryInputFile) {
        this.binaryInputFile = binaryInputFile;
    }

    public File getBinaryOutputFile() {
        return binaryOutputFile;
    }

    public void setBinaryOutputFile(File binaryOutputFile) {
        this.binaryOutputFile = binaryOutputFile;
    }

    public File getSourceInputFile() {
        return sourceInputFile;
    }

    public void setSourceInputFile(File sourceInputFile) {
        this.sourceInputFile = sourceInputFile;
    }

    public File getSourceOutputFile() {
        return sourceOutputFile;
    }

    public void setSourceOutputFile(File sourceOutputFile) {
        this.sourceOutputFile = sourceOutputFile;
    }

    public boolean isShouldBundleBinaryFile() {
        return shouldBundleBinaryFile;
    }

    public boolean isShouldBundleSourceFile() {
        return shouldBundleSourceFile;
    }
}

==> p2-maven-plugin-2.0.0-sources.jar: org/reficio/p2/bundler/ArtifactBundlerRequest.java <==
/**
 * Copyright (c) 2012 Reficio (TM) - Reestablish your software! All Rights Reserved.
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.reficio.p2.bundler;

import java.io.File;

/**
 * @author Tom Bujok (tom.bujok@gmail.com)<br>
 *         Reficio (TM) - Reestablish your software!<br>
 *         http://www.reficio.org
 * @since 1.1.0
 */
public class ArtifactBundlerRequest {

    // jar file with binaries
    private File binaryInputFile;
    private File binaryOutputFile;
    private final boolean shouldBundleBinaryFile;

    // jar file with sources
    private File sourceInputFile;
    private File sourceOutputFile;
    private final boolean shouldBundleSourceFile;

    public ArtifactBundlerRequest(File binaryInputFile, File binaryOutputFile, File sourceInputFile, File sourceOutputFile, boolean shouldBundle) {
        this.binaryInputFile = binaryInputFile;
        this.binaryOutputFile = binaryOutputFile;
        this.sourceInputFile = sourceInputFile;
        this.sourceOutputFile = sourceOutputFile;
        this.shouldBundleBinaryFile = shouldBundle;
        this.shouldBundleSourceFile = true; // source is always (re)bundled
    }

    public File getBinaryInputFile() {
        return binaryInputFile;
    }

    public void setBinaryInputFile(File binaryInputFile) {
        this.binaryInputFile = binaryInputFile;
    }

    public File getBinaryOutputFile() {
        return binaryOutputFile;
    }

    public void setBinaryOutputFile(File binaryOutputFile) {
        this.binaryOutputFile = binaryOutputFile;
    }

    public File getSourceInputFile() {
        return sourceInputFile;
    }

    public void setSourceInputFile(File sourceInputFile) {
        this.sourceInputFile = sourceInputFile;
    }

    public File getSourceOutputFile() {
        return sourceOutputFile;
    }

    public void setSourceOutputFile(File sourceOutputFile) {
        this.sourceOutputFile = sourceOutputFile;
    }

    public boolean isShouldBundleBinaryFile() {
        return shouldBundleBinaryFile;
    }

    public boolean isShouldBundleSourceFile() {
        return shouldBundleSourceFile;
    }
}
